@@ -19,7 +19,9 @@
 from collections import Counter
 from collections import defaultdict
 import functools
+import operator
 import uuid
+import warnings
 import weakref
 
 
@@ -102,6 +104,9 @@ class Proclet:
                         You can initialise that via this parameter.
         :param tally:   The instance attribute `tally` stores the number of times a transition has been enabled.
                         You can initialise that via this parameter.
+        :param priority:    A numerical value for relative priority of execution.
+                            Smaller values have higher priority.
+
         :type uid: uuid.UUID
         :type name: str
         :type channels: dict
@@ -109,6 +114,7 @@ class Proclet:
         :type marking: set
         :type slate: Counter
         :type tally: Counter
+        :type priority: int
 
         """
         name = fmt.format(len(cls.population) + 1, cls=cls)
@@ -131,40 +137,47 @@ class Proclet:
     def __init__(
         self, *args,
         uid=None, name=None, channels=None, group=None,
-        marking=None, slate=None, tally=None,
+        marking=None, slate=None, tally=None, priority=None
     ):
         self.uid = uid or uuid.uuid4()
         self.name = name or self.uid
         self.channels = channels or {}
         self.group = group or set()
-        self.arcs = dict(self.build_arcs(self.net))
         self.marking = marking or {0}
         self.slate = slate or Counter()
         self.tally = tally or Counter()
+        self.priority = priority
+        self.arcs = dict(self.build_arcs(self.net))
         self.domain = []
 
     def __call__(self, **kwargs):
-        for proc in self.domain:
-            yield from proc(**kwargs)
-
-        n = 1
-        for fn in self.enabled:
-            events = fn(fn, **kwargs) or []
-            for obj in events:
-                if obj is None:
-                    # Transition is complete
-                    self.marking -= self.i_nodes[fn]
-                    self.marking.update(self.o_nodes[fn])
-                    n = self.slate[fn] = 0
-                elif isinstance(obj, Proclet):
-                    # Transition spawns a new Proclet
-                    yield obj
-                    if obj not in self.domain:
-                        self.domain.append(obj)
-                else:
-                    yield obj
-            self.slate[fn.__name__] += n
-            self.tally[fn.__name__] += 1
+        procs = sorted(
+            ((p.priority if p.priority is not None else len(p.tally), p)
+             for p in [self] + self.domain),
+            key=operator.itemgetter(0)
+        )
+        for priority, p in procs:
+            if p is not self:
+                yield from p(**kwargs)
+            else:
+                n = 1
+                for fn in self.enabled:
+                    events = fn(fn, **kwargs) or []
+                    for obj in events:
+                        if obj is None:
+                            # Transition is complete
+                            self.marking -= self.i_nodes[fn]
+                            self.marking.update(self.o_nodes[fn])
+                            n = self.slate[fn] = 0
+                        elif isinstance(obj, Proclet):
+                            # Transition spawns a new Proclet
+                            yield obj
+                            if obj not in self.domain:
+                                self.domain.append(obj)
+                        else:
+                            yield obj
+                    self.slate[fn.__name__] += n
+                    self.tally[fn.__name__] += 1
 
     @property
     def net(self):
@@ -180,8 +193,10 @@ class Proclet:
         The list of methods currently enabled by token positions.
 
         """
-        rv = {self.arcs[i][1]: i for i in sorted(self.marking)}
-        return list(rv.keys())
+        return [i for k, i in sorted(
+            ((self.tally[i.__name__], i)
+            for i in self.net if self.i_nodes[i].issubset(self.marking)),
+            key=operator.itemgetter(0))]
 
     @functools.cached_property
     def i_nodes(self):
@@ -190,8 +205,11 @@ class Proclet:
 
         """
         rv = defaultdict(set)
+        ordinals = {i: n for n, i in enumerate(self.net)}
         for p, (s, d) in self.arcs.items():
-            rv[d].add(p)
+            if None in (s, d) or ordinals[s] < ordinals[d]:
+                # An arc to a subsequent transition creates a place
+                rv[d].add(p)
         return rv
 
     @functools.cached_property
@@ -201,6 +219,13 @@ class Proclet:
 
         """
         rv = defaultdict(set)
+        ordinals = {i: n for n, i in enumerate(self.net)}
         for p, (s, d) in self.arcs.items():
+            if None not in (s, d) and ordinals[s] >= ordinals[d]:
+                # An arc back to a previous transition does not create a place
+                try:
+                    p = ordinals[d] and sorted(self.i_nodes[s])[0]
+                except IndexError:
+                    warnings.warn(f"Missing an arc to {self.__class__.__name__}.{s.__name__}")
             rv[s].add(p)
         return rv
